@@ -38,16 +38,17 @@ class ClamsRestfulApi(Resource):
             json_str = str(json_str)
         return Response(response=json_str, status=status, mimetype='application/json')
 
-    def get(self):
+    def get(self) -> Response:
         return self.json_to_response(self.cla.appmetadata())
 
-    def post(self):
+    def post(self) -> Response:
         try:
-            accept = self.cla.sniff(Mmif(request.get_data()))
-            return Response(status=200) if accept else Response(status=406)
+            return self.json_to_response(self.cla.annotate(Mmif(request.get_data()), **request.args))
+        except TypeError as e:
+            return Response(status=415, response=str(e))
+        except FileNotFoundError as e:
+            return Response(status=404, response=str(e))
         except Exception as e:
-            return Response(status=406, response=str(e))
-
-    def put(self):
-        return self.json_to_response(self.cla.annotate(Mmif(request.get_data())))
+            return Response(status=400, response=str(e))
 
+    put = post
